@@ -978,3 +978,137 @@ void cec2021_hf03(double *x, double *f, int nx, double *Os, double *Mr, int *S,
   free(y);
   free(z);
 }
+
+void cec2022_hf01(double *x, double *f, int nx, double *Os, double *Mr, int *S,
+                  int s_flag, int r_flag) {
+  int i, tmp, cf_num = 3;
+  double fit[3];
+  int G[3], G_nx[3];
+  double Gp[3] = {0.4, 0.4, 0.2};
+
+  tmp = 0;
+  for (i = 0; i < cf_num - 1; i++) {
+    G_nx[i] = ceil(Gp[i] * nx);
+    tmp += G_nx[i];
+  }
+  G_nx[cf_num - 1] = nx - tmp;
+
+  G[0] = 0;
+  for (i = 1; i < cf_num; i++) {
+    G[i] = G[i - 1] + G_nx[i - 1];
+  }
+  double *y = calloc(nx, sizeof(double));
+  double *z = calloc(nx, sizeof(double));
+
+  sr_func(x, z, nx, Os, Mr, 1.0, s_flag, r_flag, y); /* shift and rotate */
+
+  for (i = 0; i < nx; i++) {
+    y[i] = z[S[i] - 1];
+  }
+  i = 0;
+  bent_cigar_func(&y[G[i]], &fit[i], G_nx[i], Os, Mr, 0, 0);
+  i = 1;
+  hgbat_func(&y[G[i]], &fit[i], G_nx[i], Os, Mr, 0, 0);
+  i = 2;
+  rastrigin_func(&y[G[i]], &fit[i], G_nx[i], Os, Mr, 0, 0);
+
+  f[0] = 0.0;
+  for (i = 0; i < cf_num; i++) {
+    f[0] += fit[i];
+  }
+  free(y);
+  free(z);
+}
+void cec2022_hf02(double *x, double *f, int nx, double *Os, double *Mr, int *S,
+                  int s_flag, int r_flag) {
+  int i, tmp, cf_num = 6;
+  double fit[6];
+  int G[6], G_nx[6];
+  double Gp[6] = {0.1, 0.2, 0.2, 0.2, 0.1, 0.2};
+
+  tmp = 0;
+  for (i = 0; i < cf_num - 1; i++) {
+    G_nx[i] = ceil(Gp[i] * nx);
+    tmp += G_nx[i];
+  }
+  G_nx[cf_num - 1] = nx - tmp;
+
+  G[0] = 0;
+  for (i = 1; i < cf_num; i++) {
+    G[i] = G[i - 1] + G_nx[i - 1];
+  }
+  double *y = calloc(nx, sizeof(double));
+  double *z = calloc(nx, sizeof(double));
+
+  sr_func(x, z, nx, Os, Mr, 1.0, s_flag, r_flag, y); /* shift and rotate */
+
+  for (i = 0; i < nx; i++) {
+    y[i] = z[S[i] - 1];
+  }
+
+  i = 0;
+  hgbat_func(&y[G[i]], &fit[i], G_nx[i], Os, Mr, 0, 0);
+  i = 1;
+  katsuura_func(&y[G[i]], &fit[i], G_nx[i], Os, Mr, 0, 0);
+  i = 2;
+  ackley_func(&y[G[i]], &fit[i], G_nx[i], Os, Mr, 0, 0);
+  i = 3;
+  rastrigin_func(&y[G[i]], &fit[i], G_nx[i], Os, Mr, 0, 0);
+  i = 4;
+  schwefel_func(&y[G[i]], &fit[i], G_nx[i], Os, Mr, 0, 0);
+  i = 5;
+  schaffer_F7_func(&y[G[i]], &fit[i], G_nx[i], Os, Mr, 0, 0, y);
+
+  f[0] = 0.0;
+  for (i = 0; i < cf_num; i++) {
+    f[0] += fit[i];
+  }
+
+  free(y);
+  free(z);
+}
+void cec2022_hf03(double *x, double *f, int nx, double *Os, double *Mr, int *S,
+                  int s_flag, int r_flag) {
+
+  int i, tmp, cf_num = 5;
+  double fit[5];
+  int G[5], G_nx[5];
+  double Gp[5] = {0.3, 0.2, 0.2, 0.1, 0.2};
+
+  tmp = 0;
+  for (i = 0; i < cf_num - 1; i++) {
+    G_nx[i] = ceil(Gp[i] * nx);
+    tmp += G_nx[i];
+  }
+  G_nx[cf_num - 1] = nx - tmp;
+
+  G[0] = 0;
+  for (i = 1; i < cf_num; i++) {
+    G[i] = G[i - 1] + G_nx[i - 1];
+  }
+  double *y = calloc(nx, sizeof(double));
+  double *z = calloc(nx, sizeof(double));
+
+  sr_func(x, z, nx, Os, Mr, 1.0, s_flag, r_flag, y); /* shift and rotate */
+
+  for (i = 0; i < nx; i++) {
+    y[i] = z[S[i] - 1];
+  }
+  i = 0;
+  katsuura_func(&y[G[i]], &fit[i], G_nx[i], Os, Mr, 0, 0);
+  i = 1;
+  happycat_func(&y[G[i]], &fit[i], G_nx[i], Os, Mr, 0, 0);
+  i = 2;
+  grie_rosen_func(&y[G[i]], &fit[i], G_nx[i], Os, Mr, 0, 0);
+  i = 3;
+  schwefel_func(&y[G[i]], &fit[i], G_nx[i], Os, Mr, 0, 0);
+  i = 4;
+  ackley_func(&y[G[i]], &fit[i], G_nx[i], Os, Mr, 0, 0);
+  f[0] = 0.0;
+  for (i = 0; i < cf_num; i++) {
+    f[0] += fit[i];
+  }
+
+  free(z);
+  free(y);
+}
